import React, { useEffect } from "react";
import { useThree } from "@react-three/fiber";

// store
import useModuleStore from "../../../store/useModuleStore";

// functions
import { findLinkObjects } from "./functions/findLinkObjects";
// components
import { MultiGLTFInstances } from "./MultiGLTFInstances";

// impory model from model folder
import armModel from "../../../assets/gltf-glb/rigged/ik_arm_4.glb";

// Main component to include the logic
const ArmReplace: React.FC = () => {
  const { activeModule } = useModuleStore();

  const { scene } = useThree(); // Access the Three.js scene from the React Fiber context

  // State to store positions, rotations, and count
  const [positions, setPositions] = React.useState<[number, number, number][]>(
    []
  );
  const [rotations, setRotations] = React.useState<[number, number, number][]>(
    []
  );
  const [count, setCount] = React.useState<string[]>([]);

  useEffect(() => {
    // Call the function to find objects and update states
    findLinkObjects(
      scene,
      setPositions,
      setRotations,
      setCount,
      activeModule === "simulation" ? false : true
    );
  }, [scene, activeModule]); // Re-run this effect if the scene changes or activeModule changes

  return (
    <>
      {useModuleStore.getState().activeModule === "simulation" &&
        count.map((_, i: number) => (
          <MultiGLTFInstances
            index={i}
            modelUrl={armModel}
            position={positions[i]}
            rotation={rotations[i]}
          />
        ))}
    </>
  );
};

export default ArmReplace;
