import { Object3D, Vector3 } from "three";

// Function to find objects named 'link_0' and update positions, rotations, and count
export const findLinkObjects = (
  scene: Object3D,
  setPositions: React.Dispatch<
    React.SetStateAction<[number, number, number][]>
  >,
  setRotations: React.Dispatch<
    React.SetStateAction<[number, number, number][]>
  >,
  setCount: React.Dispatch<React.SetStateAction<string[]>>,
  visibility: boolean
) => {
  const positions: [number, number, number][] = [];
  const rotations: [number, number, number][] = [];
  const count: string[] = [];
  let i = 0;

  scene.traverse((object) => {
    if (object.name === "link_0") {
      if (object.parent && object.type !== "SkinnedMesh") {
        // count
        count[i] = object.uuid;
        i++;
        // Save the position and rotation of the parent object
        const { x: px, y: py, z: pz } = object.parent.position;
        positions.push([px, py, pz]);

        const { x: rx, y: ry, z: rz } = object.parent.rotation;
        rotations.push([rx, ry, rz]);

        // Change visibility of the object
        object.visible = visibility;
      }
    }
  });

  // Update the state with the collected positions, rotations, and count
  setPositions(positions);
  setRotations(rotations);
  setCount(count);
};
